@@ -1,4 +1,4 @@
-/***************************************************** vim:set ts=4 sw=4 sts=4:
+/*
   This file is the template for the configuration plug ins.
   -------------------
   Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández
@@ -208,7 +208,7 @@
 */
 
 class KDE_EXPORT PlugInConf : public TQWidget{
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
